@@ -7,10 +7,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     Revised BSD License for more details.
 
-    Copyright 2011-2015 Game Maker 2k - https://github.com/GameMaker2k
-    Copyright 2011-2015 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
+    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
+    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: oopfuncs.py - Last Update: 1/15/2015 Ver. 2.7.10 RC 1  - Author: cooldude2k $
+    $FileInfo: oopfuncs.py - Last Update: 2/18/2023/18/2023 Ver. 2.7.20 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -60,7 +60,6 @@ class barcode:
   self.bgcolor = (255, 255, 255);
   self.return_check = False;
   self.return_type = "dict";
-  self.barcode_type = "upca";
  ''' // support.py funtions '''
  def supported_barcodes(self, return_type=None):
   if(return_type is None):
