@@ -7,10 +7,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     Revised BSD License for more details.
 
-    Copyright 2011-2015 Game Maker 2k - https://github.com/GameMaker2k
-    Copyright 2011-2015 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
+    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
+    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: validate.py - Last Update: 1/15/2015 Ver. 2.7.10 RC 1  - Author: cooldude2k $
+    $FileInfo: validate.py - Last Update: 2/18/2023/18/2023 Ver. 2.7.20 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -163,6 +163,35 @@ def fix_ean13_checksum(upc):
   upc = fix_matches[0];
  return upc+str(get_ean13_checksum(upc));
 
+def validate_itf6_checksum(upc, return_check=False):
+ upc = str(upc);
+ if(len(upc)>6):
+  fix_matches = re.findall("^(\d{6})", upc); 
+  upc = fix_matches[0];
+ if(len(upc)>6 or len(upc)<5):
+  return False;
+ upc_matches = list(upc);
+ upc_matches = [int(x) for x in upc_matches];
+ CheckSum = 10 - ( ( 3 * upc_matches[0] + upc_matches[1] + 3 * upc_matches[2] + upc_matches[3] + 3 * upc_matches[4] ) % 10 );
+ if(not return_check and len(upc)==6):
+  if(CheckSum!=upc_matches[5]):
+   return False;
+  if(CheckSum==upc_matches[5]):
+   return True;
+ if(return_check):
+  return str(CheckSum);
+ if(len(upc)==5):
+  return str(CheckSum);
+def get_itf6_checksum(upc):
+ upc = str(upc);
+ return validate_itf6_checksum(upc,True);
+def fix_itf6_checksum(upc):
+ upc = str(upc);
+ if(len(upc)>5):
+  fix_matches = re.findall("^(\d{5})", upc); 
+  upc = fix_matches[0];
+ return upc+str(get_itf6_checksum(upc));
+
 def validate_itf14_checksum(upc, return_check=False):
  upc = str(upc);
  if(len(upc)>14):
@@ -481,11 +510,12 @@ def validate_ups_checksum(upc, return_check=False):
   return str(CheckSum);
 def get_ups_checksum(upc):
  upc = str(upc);
+ print(upc);
  return validate_ups_checksum(upc,True);
 def fix_ups_checksum(upc):
  upc = str(upc);
- if(len(upc)>15):
-  fix_matches = re.findall("^(\d{15})", upc); 
+ if(len(upc)>17):
+  fix_matches = re.findall("^(\w{17})", upc); 
   upc = fix_matches[0];
  return upc+str(get_ups_checksum(upc));
 
@@ -698,6 +728,41 @@ def get_code93_checksum(upc):
  CheckSum = str(CheckSum)+str(Code93Array[UPC_Sum % 47]);
  return str(CheckSum);
 
+'''
+// Code 93
+// Source: http://www.barcodeisland.com/code128.phtml
+// Source: http://en.wikipedia.org/wiki/Code_128
+'''
+def get_code128_checksum(upc):
+ if(len(upc) % 2):
+  return False;
+ if(len(upc) < 6): 
+  return False;
+ if(not re.findall("([0-9a-f]+)", upc)):
+  return False;
+ upc = upc.lower();
+ upc_matches = re.findall("[0-9a-f]{2}", upc);
+ upc_to_dec = list([int(x, 16) for x in upc_matches]);
+ icount = 1;
+ icountadd = 1;
+ checksum = 0;
+ if(upc_to_dec[0]>102 and upc_to_dec[0]<106):
+  checksum = checksum + upc_to_dec[0];
+  icount = 1;
+ else:
+  checksum = 0;
+  icount = 0;
+ upc_less_count = len(upc_to_dec) - 1;
+ while(icount < len(upc_to_dec)):
+  if(icount==upc_less_count and (upc_to_dec[icount]>105 and upc_to_dec[icount]<108)):
+   checksum = checksum;
+  else:
+   checksum = checksum + (upc_to_dec[icount] * icountadd);
+  icount = icount + 1;
+  icountadd = icountadd + 1;
+ checksum = str(format(checksum % 103, 'x'));
+ return checksum;
+
 '''
 // MSI (Modified Plessey)
 // Source: http://www.barcodeisland.com/msi.phtml
